"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tokenize_1 = require("./tokenize");
const fs = require("fs-extra");
class Grammar {
    constructor(grammarDef) {
        this.grammarDef = grammarDef;
    }
    tokenizer() {
        let rule = tokenize_1.grammarToRule(this.grammarDef);
        return {
            tokenize: (line) => {
                const r = tokenize_1.tokenizeLine(line, rule);
                rule = r.state;
                return r.tokens;
            }
        };
    }
    *tokenizeLines(input) {
        const tokenizer = this.tokenizer();
        let lineNumber = 0;
        for (const line of input) {
            lineNumber += 1;
            const tokens = tokenizer.tokenize(line);
            yield { line, lineNumber, tokens };
        }
    }
    static async createFromFile(filename) {
        const json = await fs.readFile(filename, 'utf8');
        const grammarDef = JSON.parse(json);
        return new Grammar(grammarDef);
    }
}
exports.Grammar = Grammar;
//# sourceMappingURL=grammar.js.map