/**
 * @see https://manual.macromates.com/en/language_grammars
 */
export interface GrammarDefinition extends PatternPatterns {
    name: string;
    scopeName: Scope;
    fileTypes: string[];
    patterns: Pattern[];
    repository?: Repository;
}
export declare type Pattern = PatternMatch | PatternBeginEnd | PatternInclude | PatternPatterns | PatternName;
export interface PatternMatch extends PatternBase {
    name?: Scope;
    comment?: string;
    match: RegexOrString;
    captures?: Capture;
}
export interface PatternBeginEnd extends PatternBase {
    name: Scope;
    comment?: string;
    begin: RegexOrString;
    end: RegexOrString;
    captures?: Capture;
    beginCaptures?: Capture;
    endCaptures?: Capture;
    contentName?: string;
    patterns?: Pattern[];
}
export interface PatternInclude extends PatternBase {
    /**
     * Include a named pattern or grammar
     * Example: "#comment" -- include the "comment" pattern from the repository.
     * Example: "$self" -- to nest the entire grammar.
     * Example: "source.json" -- to include the rules for .json files (not supported)
     */
    include: string;
    comment?: string;
}
export interface PatternPatterns extends PatternBase {
    patterns: Pattern[];
    comment?: string;
    scopeName?: Scope;
}
export interface PatternName extends PatternBase {
    name: Scope;
}
export interface PatternBase {
    name?: Scope;
    comment?: string;
}
export declare type RegexOrString = RegExp | string;
export interface Capture {
    [index: string]: Pattern;
    [index: number]: Pattern;
}
export interface Repository {
    [index: string]: Pattern;
}
/**
 * the Scope is used to define a space separated set of scope values to apply if the pattern matches.
 * Example scope: "meta.definition.variable.js variable.other.readwrite.js"
 * The space separated values go from general on the left to specific on the right.
 * All scope values should end in the language.
 */
export declare type Scope = string;
