"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const colorMap = [
    [/ keyword/, chalk_1.default.yellow],
    [/ entity.name/, chalk_1.default.blue],
    [/ variable/, chalk_1.default.greenBright],
    [/ string/, chalk_1.default.yellowBright],
    [/comment/, chalk_1.default.dim.green],
    [/ punctuation/, chalk_1.default.yellow],
    [/support.function/, chalk_1.default.greenBright],
    [/^source$/, chalk_1.default.gray]
];
function colorize(text, scopes) {
    for (const [reg, fn] of colorMap) {
        if (reg.test(scopes)) {
            return fn(text);
        }
    }
    return text;
}
exports.colorize = colorize;
function* formatTokenizeText(text, grammar, colorizer = colorize) {
    for (const tr of grammar.tokenizeLines(text.split('\n'))) {
        const { line: rawLine, lineNumber, tokens } = tr;
        const line = rawLine.replace(/\t/g, ' ');
        yield `${lineNumber} ${line}`;
        const results = tokens.map(t => ({ text: line.slice(t.startIndex, t.endIndex), scopes: t.scopes.join(' ') }));
        const w = Math.max(...results.map(t => t.text.length));
        for (const { text, scopes } of results) {
            yield `  ${colorizer(text.padEnd(w + 2), scopes)} => ${scopes}`;
        }
        yield '';
    }
}
exports.formatTokenizeText = formatTokenizeText;
//# sourceMappingURL=display.js.map