"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs = require("fs-extra");
const path = require("path");
const defaultEncoding = 'utf8';
function tokenizeLineToMd(tokenizedLine) {
    const { line, lineNumber, tokens } = tokenizedLine;
    const lineText = line ? ('``` ' + line + ' ```') : '*blank line*';
    const parts = [
        `**${lineNumber}:** ${lineText}`,
        ''
    ];
    if (tokens.length) {
        parts.push('| text | scope |');
        parts.push('| -- | -- |');
        for (const t of tokens) {
            parts.push(`| \`\`\` ${line.slice(t.startIndex, t.endIndex)} \`\`\` | ${t.scopes.join(' ')} |`);
        }
        parts.push('');
    }
    return parts.join('\n');
}
exports.tokenizeLineToMd = tokenizeLineToMd;
function* tokenizeTextToMd(grammar, text) {
    for (const t of grammar.tokenizeLines(text.split(/\r?\n/))) {
        yield tokenizeLineToMd(t);
    }
}
exports.tokenizeTextToMd = tokenizeTextToMd;
async function tokenizeFileToMd(grammar, filename, encoding = defaultEncoding) {
    const text = await fs.readFile(filename, encoding);
    const name = path.basename(filename);
    return [
        `# ${name}`,
        '',
        ...tokenizeTextToMd(grammar, text),
        ''
    ].join('\n');
}
exports.tokenizeFileToMd = tokenizeFileToMd;
//# sourceMappingURL=tokenizeToMd.js.map